==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/glue/kotlin/inputs/PartitionIndexPartitionIndexArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.glue.kotlin.inputs

import com.pulumi.aws.glue.inputs.PartitionIndexPartitionIndexArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property indexName Name of the partition index.
 * @property indexStatus
 * @property keys Keys for the partition index.
 */
public data class PartitionIndexPartitionIndexArgs(
    public val indexName: Output<String>? = null,
    public val indexStatus: Output<String>? = null,
    public val keys: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.aws.glue.inputs.PartitionIndexPartitionIndexArgs> {
    override fun toJava(): com.pulumi.aws.glue.inputs.PartitionIndexPartitionIndexArgs =
        com.pulumi.aws.glue.inputs.PartitionIndexPartitionIndexArgs.builder()
            .indexName(indexName?.applyValue({ args0 -> args0 }))
            .indexStatus(indexStatus?.applyValue({ args0 -> args0 }))
            .keys(keys?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [PartitionIndexPartitionIndexArgs].
 */
@PulumiTagMarker
public class PartitionIndexPartitionIndexArgsBuilder internal constructor() {
    private var indexName: Output<String>? = null

    private var indexStatus: Output<String>? = null

    private var keys: Output<List<String>>? = null

    /**
     * @param value Name of the partition index.
     */
    @JvmName("hmsiacjqocpqyhyd")
    public suspend fun indexName(`value`: Output<String>) {
        this.indexName = value
    }

    /**
     * @param value
     */
    @JvmName("kqryoacmqrfkewqc")
    public suspend fun indexStatus(`value`: Output<String>) {
        this.indexStatus = value
    }

    /**
     * @param value Keys for the partition index.
     */
    @JvmName("oylkacflrgrjqckm")
    public suspend fun keys(`value`: Output<List<String>>) {
        this.keys = value
    }

    @JvmName("weeubvayhjweauva")
    public suspend fun keys(vararg values: Output<String>) {
        this.keys = Output.all(values.asList())
    }

    /**
     * @param values Keys for the partition index.
     */
    @JvmName("eymjwmluquvdejef")
    public suspend fun keys(values: List<Output<String>>) {
        this.keys = Output.all(values)
    }

    /**
     * @param value Name of the partition index.
     */
    @JvmName("pqphcqlrndcctqji")
    public suspend fun indexName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.indexName = mapped
    }

    /**
     * @param value
     */
    @JvmName("rstivbgkvxbijgnh")
    public suspend fun indexStatus(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.indexStatus = mapped
    }

    /**
     * @param value Keys for the partition index.
     */
    @JvmName("ridxdfwjpktgiijd")
    public suspend fun keys(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.keys = mapped
    }

    /**
     * @param values Keys for the partition index.
     */
    @JvmName("lvqsaugworatyaif")
    public suspend fun keys(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.keys = mapped
    }

    internal fun build(): PartitionIndexPartitionIndexArgs = PartitionIndexPartitionIndexArgs(
        indexName = indexName,
        indexStatus = indexStatus,
        keys = keys,
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/glue/kotlin/inputs/PartitionIndexPartitionIndexArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.glue.kotlin.inputs

import com.pulumi.aws.glue.inputs.PartitionIndexPartitionIndexArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property indexName Name of the partition index.
 * @property indexStatus
 * @property keys Keys for the partition index.
 */
public data class PartitionIndexPartitionIndexArgs(
    public val indexName: Output<String>? = null,
    public val indexStatus: Output<String>? = null,
    public val keys: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.aws.glue.inputs.PartitionIndexPartitionIndexArgs> {
    override fun toJava(): com.pulumi.aws.glue.inputs.PartitionIndexPartitionIndexArgs =
        com.pulumi.aws.glue.inputs.PartitionIndexPartitionIndexArgs.builder()
            .indexName(indexName?.applyValue({ args0 -> args0 }))
            .indexStatus(indexStatus?.applyValue({ args0 -> args0 }))
            .keys(keys?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [PartitionIndexPartitionIndexArgs].
 */
@PulumiTagMarker
public class PartitionIndexPartitionIndexArgsBuilder internal constructor() {
    private var indexName: Output<String>? = null

    private var indexStatus: Output<String>? = null

    private var keys: Output<List<String>>? = null

    /**
     * @param value Name of the partition index.
     */
    @JvmName("ebnovcopjodbhdhp")
    public suspend fun indexName(`value`: Output<String>) {
        this.indexName = value
    }

    /**
     * @param value
     */
    @JvmName("xaapirphsmckrqsi")
    public suspend fun indexStatus(`value`: Output<String>) {
        this.indexStatus = value
    }

    /**
     * @param value Keys for the partition index.
     */
    @JvmName("fmchpdpmnsxjqsud")
    public suspend fun keys(`value`: Output<List<String>>) {
        this.keys = value
    }

    @JvmName("tnqcextyfvduhpry")
    public suspend fun keys(vararg values: Output<String>) {
        this.keys = Output.all(values.asList())
    }

    /**
     * @param values Keys for the partition index.
     */
    @JvmName("gutquffcbjqyufil")
    public suspend fun keys(values: List<Output<String>>) {
        this.keys = Output.all(values)
    }

    /**
     * @param value Name of the partition index.
     */
    @JvmName("qgtdlujxxgpulhxm")
    public suspend fun indexName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.indexName = mapped
    }

    /**
     * @param value
     */
    @JvmName("omkkifylibvcojok")
    public suspend fun indexStatus(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.indexStatus = mapped
    }

    /**
     * @param value Keys for the partition index.
     */
    @JvmName("wksasybhpcumugdj")
    public suspend fun keys(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.keys = mapped
    }

    /**
     * @param values Keys for the partition index.
     */
    @JvmName("bphufllgedcafwqg")
    public suspend fun keys(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.keys = mapped
    }

    internal fun build(): PartitionIndexPartitionIndexArgs = PartitionIndexPartitionIndexArgs(
        indexName = indexName,
        indexStatus = indexStatus,
        keys = keys,
    )
}
